@@ -1,8 +1,5 @@
 from abc import ABC, abstractmethod
 import multiprocessing
-from typing import Dict, List
-from FreeTAKServer.model.ClientInformation import ClientInformation
-from FreeTAKServer.model.SQLAlchemy.User import User
 
 class ServiceInterface(ABC):
 
@@ -26,20 +23,11 @@ class ServerServiceInterface(ServiceInterface):
 
 class ServiceBase(ServiceInterface):
 
-    @abstractmethod
-    def get_service_users(self) -> List[User]:
-        """ the implementation of this method
-
-        Returns Dict[str, ClientInformation]: a dictionary of client uid's and their associated objects
-
-        """
-        raise NotImplementedError
-
     def receive_command_data(self, pipe: multiprocessing.Pipe) -> any:
-        if not pipe.empty():
-            return pipe.get()
+        if pipe.poll():
+            return pipe.recv()
         else:
             return None
 
     def define_responsibility_chain(self):
-        raise NotImplementedError
\ No newline at end of file
+        pass
\ No newline at end of file
