@@ -1,6 +1,7 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.UidVariables import UidVariables as vars
 
-class Uid:
+class Uid(FTSProtocolObject):
     def __init__(self):
         self.Droid = None
 
